UnsignedWithMontyForm

Trait UnsignedWithMontyForm 

pub trait UnsignedWithMontyForm: Unsigned {
    type MontyForm: MontyForm<Integer = Self>;
}
Unsigned integers with an associated MontyForm.

Required Associated Types

type MontyForm: MontyForm<Integer = Self>

The corresponding Montgomery representation, optimized for the performance of modular operations at the price of a conversion overhead.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<const LIMBS: usize> UnsignedWithMontyForm for Uint<LIMBS>